@@ -48,7 +48,7 @@ CrashInformationPage::CrashInformationPage(ReportAssistantDialog *parent)
     m_backtraceWidget = new BacktraceWidget(DrKonqi::debuggerManager()->backtraceGenerator(), this, true);
     connect(m_backtraceWidget, &BacktraceWidget::stateChanged, this, &CrashInformationPage::emitCompleteChanged);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_backtraceWidget);
     layout->addSpacing(10); // We need this for better usability until we get something better
@@ -66,7 +66,7 @@ CrashInformationPage::CrashInformationPage(ReportAssistantDialog *parent)
 void CrashInformationPage::aboutToShow()
 {
     m_backtraceWidget->generateBacktrace();
-    m_backtraceWidget->hilightExtraDetailsLabel(false);
+    m_backtraceWidget->highlightExtraDetailsLabel(false);
     emitCompleteChanged();
 }
 
@@ -104,7 +104,7 @@ bool CrashInformationPage::showNextPage()
                                                 "do you want to try to improve it? You will need "
                                                 "to install some debugging packages."),
                                           i18nc("@title:window", "Crash Information is not useful enough"))) {
-            m_backtraceWidget->hilightExtraDetailsLabel(true);
+            m_backtraceWidget->highlightExtraDetailsLabel(true);
             m_backtraceWidget->focusImproveBacktraceButton();
             return false; // Cancel show next, to allow the user to write more
         } else {
@@ -267,7 +267,7 @@ void ConclusionPage::aboutToShow()
         if (!DrKonqi::crashedApplication()->hasBeenRestarted()) {
             ui.m_restartAppOnFinish->setVisible(true);
         }
-        emit finished(false /* don't enable back button - the user can't improve this result*/);
+        Q_EMIT finished(false /* don't enable back button - the user can't improve this result*/);
         return;
     }
 
@@ -386,7 +386,7 @@ void ConclusionPage::aboutToShow()
                                                    "report at <link>%1</link>.",
                                                    reportAddress));
 
-            emit finished(false);
+            Q_EMIT finished(false);
         }
 
     } else { // (m_needToReport)
@@ -424,7 +424,7 @@ void ConclusionPage::aboutToShow()
                                                        reportAddress));
             }
         }
-        emit finished(true);
+        Q_EMIT finished(true);
     }
 }
 
@@ -464,7 +464,7 @@ ReportInformationDialog::ReportInformationDialog(const QString &reportText)
     ui.setupUi(this);
     ui.m_reportInformationBrowser->setPlainText(reportText);
 
-    QPushButton *saveButton = new QPushButton(ui.buttonBox);
+    auto *saveButton = new QPushButton(ui.buttonBox);
     KGuiItem::assign(saveButton,
                      KGuiItem2(i18nc("@action:button", "&Save to File..."),
                                QIcon::fromTheme(QStringLiteral("document-save")),
