@@ -18,6 +18,20 @@ class CrashedApplication : public QObject
 {
     Q_OBJECT
 public:
+    CrashedApplication(int pid,
+                       int thread,
+                       int signalNumber,
+                       const QFileInfo &executable,
+                       const QString &version,
+                       const BugReportAddress &reportAddress,
+                       const QString &name = QString(),
+                       const QString &productName = QString(),
+                       const QDateTime &datetime = QDateTime::currentDateTime(),
+                       bool restarted = false,
+                       bool hasDeletedFiles = false,
+                       const QString &fakeBaseName = QString(),
+                       QObject *parent = nullptr);
+
     ~CrashedApplication() override;
 
     /** Returns the crashed program's name, possibly translated (ex. "The KDE Crash Handler") */
@@ -40,6 +54,9 @@ public:
     /** Returns the address where the bug report for this application should go */
     BugReportAddress bugReportAddress() const;
 
+    /** Bugzialla product name, if the crashed application has explicitly specified that. */
+    QString productName() const;
+
     /** Returns the pid of the crashed program */
     int pid() const;
 
@@ -65,9 +82,6 @@ Q_SIGNALS:
     void restarted(bool success);
 
 protected:
-    friend class KCrashBackend;
-    CrashedApplication(QObject *parent = nullptr);
-
     int m_pid;
     int m_signalNumber;
     QString m_name;
@@ -75,6 +89,7 @@ protected:
     QString m_fakeBaseName;
     QString m_version;
     BugReportAddress m_reportAddress;
+    QString m_productName;
     bool m_restarted;
     int m_thread;
     QDateTime m_datetime;
